@@ -66,9 +66,15 @@ class LinearRing(LineString):
 
     @property
     def is_ccw(self):
-        """Brand new"""
+        """True is the ring is oriented counter clock-wise"""
         return bool(self.impl['is_ccw'](self))
 
+    @property
+    def is_simple(self):
+        """True if the geometry is simple, meaning that any self-intersections
+        are only at boundary points, else False"""
+        return LineString(self).is_simple
+
 
 class LinearRingAdapter(LineStringAdapter):
 
@@ -424,7 +430,7 @@ def update_linearring_from_py(geom, ob):
 def geos_polygon_from_py(shell, holes=None):
     if shell is not None:
         geos_shell, ndim = geos_linearring_from_py(shell)
-        if holes:
+        if holes is not None and len(holes) > 0:
             ob = holes
             L = len(ob)
             exemplar = ob[0]
@@ -432,8 +438,10 @@ def geos_polygon_from_py(shell, holes=None):
                 N = len(exemplar[0])
             except TypeError:
                 N = exemplar._ndim
-            assert L >= 1
-            assert N == 2 or N == 3
+            if not L >= 1:
+                raise ValueError("number of holes must be non zero")
+            if not N in (2, 3):
+                raise ValueError("insufficiant coordinate dimension")
 
             # Array of pointers to ring geometries
             geos_holes = (c_void_p * L)()
